@@ -23,7 +23,7 @@ class ROIExtractionThread(Thread):
                 self.data_handler.calculate_roi_extraction()
                 print("Finished ROI extraction")
                 self.signal.sig.emit(True)
-            except Exception as e:
+            except AttributeError as e:
                 if (type(e) == AssertionError):
                     print(e.args[0])
                 else:
@@ -37,7 +37,7 @@ class ROIExtractionThread(Thread):
         if not any([x.isRunning() for x in self.main_widget.thread_list]):
             print("Starting ROI extraction")
             # self.button.setEnabled(False)
-            self.start()
+            self.run()
         else:
             print(
                 "Previous process in process, please wait to start new one till finished")
