@@ -16,3 +16,7 @@ class Thread(QThread):
 
     def endThread(self, success):
         pass
+
+    def __del__(self):
+        self.exiting = True
+        self.wait()
