@@ -134,8 +134,17 @@ class ROIImageViewModule(ImageViewModule):
             #     self.current_background = self.data_handler.temporal_correlation_image.reshape(
             #         [-1, 1])
             elif func_name == "Eigen Norm Image":
-                self.current_background = self.data_handler.eigen_norm_image.reshape(
-                    [-1, 1])
+                try:
+                    self.current_background = self.data_handler.eigen_norm_image.reshape(
+                        [-1, 1])
+                except AttributeError:
+                    print("Eigen vectors aren't currently generated or valid")
+                    self.current_background = self.main_widget.data_handler.max_images[
+                                                  self.data_handler.trials_loaded.index(
+                                                      self.trial_selector_input.current_state())][
+                                              :].reshape(
+                        [-1, 1])
+                    self.current_background_name = "Max Image"
             else:
                 self.current_background_name = "Max Image"
                 self.current_background = self.main_widget.data_handler.max_images[
@@ -226,6 +235,8 @@ class ROIImageViewModule(ImageViewModule):
             self.updateImageDisplay()
         except AttributeError:
             pass
+        except IndexError:
+            print("Please regenerate ROIs before trying this operation")
         except ValueError as e:
             if "shape" in e.args[0]:
                 print("Error please try again")
@@ -418,6 +429,13 @@ class ROIImageViewModule(ImageViewModule):
 
                 else:
                     self.roi_image_flat = self.main_widget.data_handler.pixel_with_rois_color_flat
+            if len(self.trial_selector_input.val_list) != len(
+                    self.data_handler.trials_loaded) or any(
+                    [x != y for x, y in zip(self.trial_selector_input.val_list,
+                                            self.data_handler.trials_loaded)]):
+                self.trial_selector_input.set_new_options(
+                    self.data_handler.trials_loaded)
+
             self.set_background("", self.current_background_name, update_image=False)
             if (updateDisplay):
                 self.updateImageDisplay(new=True)
