@@ -24,3 +24,12 @@ class OptionInput(Input):
 
     def set_default_val(self):
         self.input_box.setCurrentIndex(self.default_val)
+
+    def set_new_options(self, options, default_index=0):
+        for x in self.val_list:
+            self.input_box.removeItem(0)
+
+        self.val_list = options
+        self.input_box.addItems(options)
+        self.default_val = default_index
+        self.set_default_val()
