@@ -10,12 +10,13 @@ from scipy.sparse import linalg
 from CIDAN.LSSC.SpatialBox import combine_images
 from CIDAN.LSSC.functions.embeddings import calcDInv, calcDSqrt, calcDNegSqrt
 from CIDAN.LSSC.functions.pickle_funcs import pickle_save, pickle_load
-from matplotlib import pyplot as plt
+
 logger1 = logging.getLogger("CIDAN.LSSC.eigen")
 
 
 @delayed
-def generateEigenVectors(*, K: sparse.csr_matrix, num_eig: int) -> np.ndarray:
+def generateEigenVectors(*, K: sparse.csr_matrix, num_eig: int, maxiter=7,
+                         accuracy=1E-4) -> np.ndarray:
     """Calculate Eigen Vectors given parts of the affinity matrix
 
     Parameters
@@ -33,13 +34,16 @@ def generateEigenVectors(*, K: sparse.csr_matrix, num_eig: int) -> np.ndarray:
     P = D_inv.dot(K)
     D_neg_sqrt = calcDNegSqrt(D_diag)
     P_transformed = calcDSqrt(D_diag).dot(P).dot(D_neg_sqrt)
-    # print("Start eigen")
+    print("Start eigen", num_eig)
+    print(accuracy)
     # eig_values,eig_vectors = eig(P.todense())
+    # io.savemat("C:\\Users\\gadge\\Documents\\CIDAN\\inputs\\P.mat", {"array": P)}
 
     eig_values, eig_vectors_scaled = linalg.eigsh(
         P_transformed, num_eig, which="LM",
-        return_eigenvectors=True)  # this returns normalized eigen vectors
-    # print("finished eigen")
+        return_eigenvectors=True, maxiter=maxiter * num_eig,
+        tol=accuracy)  # this returns normalized eigen vectors
+    print("finished eigen")
     # # TODO make first eigen vector be sanity check since all elements are the same
     # #  this isn't the case
     # # print("Eigvalues",eig_values[0], eig_vectors_scaled,np.max(eig_vectors_scaled),eig_vectors_scaled.shape, num_eig)
@@ -53,12 +57,15 @@ def generateEigenVectors(*, K: sparse.csr_matrix, num_eig: int) -> np.ndarray:
 @delayed
 def saveEigenVectors(*, e_vectors, spatial_box_num: int, time_box_num: int, save_dir:
 str):
+    print("save Eigen", time_box_num, " ", spatial_box_num)
     eigen_dir = os.path.join(save_dir, "eigen_vectors")
     if not os.path.isdir(eigen_dir):
         os.mkdir(eigen_dir)
     pickle_save(e_vectors, name="eigen_vectors_box_{}_{}.pickle".format(spatial_box_num,
                                                                         time_box_num),
                 output_directory=eigen_dir, )
+    print("save Eigen done", time_box_num, " ", spatial_box_num)
+
     return e_vectors
 
 
@@ -79,7 +86,7 @@ def loadEigenVectors(*, spatial_box_num: int, time_box_num: int, save_dir: str):
 
 @delayed
 def saveEmbedingNormImage(*, e_vectors, image_shape, save_dir, spatial_box_num):
-    # print(save_dir)
+    print("Eigen norm step")
     embed_dir = os.path.join(save_dir, "embedding_norm_images")
     e_vectors_squared = np.power(e_vectors, 2)
     e_vectors_sum = np.sum(e_vectors_squared, axis=1)
@@ -141,8 +148,8 @@ def createEmbedingNormImageFromMultiple(*, spatial_box_list, save_dir, num_time_
     img = Image.fromarray(((image-percent_05)/(percent_95-percent_05)) * 255).convert('L')
     image_path = os.path.join(embed_dir, "embedding_norm_image.png")
     img.save(image_path)
-    plt.imshow(img)
-    plt.savefig(os.path.join(embed_dir, "embedding_norm_matlab.png"))
-    plt.close()
+    # plt.imshow(img)
+    # plt.savefig(os.path.join(embed_dir, "embedding_norm_matlab.png"))
+    # plt.close()
 
     return e_vectors_list
