@@ -1,12 +1,12 @@
 import os
 
-from matplotlib import pyplot as plt
+# from matplotlib import pyplot as plt
 
-os.environ["OMP_NUM_THREADS"] = "10"  # export OMP_NUM_THREADS=4
-os.environ["OPENBLAS_NUM_THREADS"] = "10"  # export OPENBLAS_NUM_THREADS=4
-os.environ["MKL_NUM_THREADS"] = "10"  # export MKL_NUM_THREADS=6
-os.environ["VECLIB_MAXIMUM_THREADS"] = "10"  # export VECLIB_MAXIMUM_THREADS=4
-os.environ["NUMEXPR_NUM_THREADS"] = "10"  # export NUMEXPR_NUM_THREADS=6
+# os.environ["OMP_NUM_THREADS"] = "10"  # export OMP_NUM_THREADS=4
+# os.environ["OPENBLAS_NUM_THREADS"] = "10"  # export OPENBLAS_NUM_THREADS=4
+# os.environ["MKL_NUM_THREADS"] = "10"  # export MKL_NUM_THREADS=6
+# os.environ["VECLIB_MAXIMUM_THREADS"] = "10"  # export VECLIB_MAXIMUM_THREADS=4
+# os.environ["NUMEXPR_NUM_THREADS"] = "10"  # export NUMEXPR_NUM_THREADS=6
 import scipy.sparse as sparse
 import hnswlib as hnsw
 import numpy as np
@@ -108,15 +108,16 @@ def calcAffinityMatrix(*, pixel_list: np.ndarray, metric: str, knn: int,
 
 
 def save_image(image, num):
-    print(image.diagonal())
-    plt.imshow(
-        image, aspect="auto")
-    plt.colorbar()
-    path = os.path.join("/Users/sschickler/Code_Devel/LSSC-python/input_images/test",
-                        "eigen{}.png".format(
-                            num))
-    plt.savefig(path, dpi=300)
-    plt.close()
+    pass
+    # print(image.diagonal())
+    # plt.imshow(
+    #     image, aspect="auto")
+    # plt.colorbar()
+    # path = os.path.join("/Users/sschickler/Code_Devel/LSSC-python/input_images/test",
+    #                     "eigen{}.png".format(
+    #                         num))
+    # plt.savefig(path, dpi=300)
+    # plt.close()
     # image
     # img.save(image_path)
 def calcDInv(K: sparse.csr_matrix):
